@@ -1479,6 +1479,35 @@ plt({
 	'shared.colorbar' => [0,1], # plots 0 and 1 share a colorbar
 	suptitle          => 'Dictionary of Secondary Structure in Proteins (DSSP)',
 });
+my @plots = ({
+	data => {
+			'sin' => [map {sin($_ * 3.14159265/180)} 0..360],
+			'cos' => [map {cos($_ * 3.14159265/180)} 0..360]
+		},
+	'plot.type' => 'hist2d',
+	cbpad       => 0.001,
+	title       => 'pad = 0.001'
+});
+for (my $pad = 0.01; $pad <= 0.09; $pad += 0.03) {
+	push @plots, {
+		data => {
+			'sin' => [map {sin($_ * 3.14159265/180)} 0..360],
+			'cos' => [map {cos($_ * 3.14159265/180)} 0..360]
+		},
+		'plot.type' => 'hist2d',
+		cbpad       => $pad,
+		title       => "pad = $pad"
+	};
+}
+plt({
+	execute       => 0,
+	fh            => $fh,
+	'output.file' => 'output.images/hist2d.pads.png',
+	plots         => \@plots,
+	ncols         => 2,
+	nrows         => 2,
+	scale         => 2
+});
 plt({
 	fh                => $fh,
 	execute           => 1,
